@@ -93,7 +93,9 @@ main (int    argc,
 
 	retval = 0;
 
+#if !GLIB_CHECK_VERSION (2, 36, 0)
 	g_type_init ();
+#endif
 
 	context = g_option_context_new ("");
 	g_option_context_add_main_entries (context, options, NULL);
