@@ -476,7 +476,6 @@ gboolean workspace_switcher_applet_fill(MatePanelApplet* applet)
 	GtkActionGroup* action_group;
 	gchar* ui_path;
 	gboolean display_names;
-	gboolean wrap_workspaces;
 
 	pager = g_new0(PagerData, 1);
 
@@ -492,7 +491,7 @@ gboolean workspace_switcher_applet_fill(MatePanelApplet* applet)
 
 	display_names = g_settings_get_boolean(pager->settings, "display-workspace-names");
 
-	wrap_workspaces = g_settings_get_boolean(pager->settings, "wrap-workspaces");
+	pager->wrap_workspaces = g_settings_get_boolean(pager->settings, "wrap-workspaces");
 
 	if (display_names)
 	{
@@ -839,6 +838,11 @@ static void setup_dialog(GtkBuilder* builder, PagerData* pager)
 
 
 	/* Wrap workspaces: */
+	if (pager->wrap_workspaces_toggle)
+	{
+		/* make sure the toggle button resembles the value of wrap_workspaces */
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pager->wrap_workspaces_toggle), pager->wrap_workspaces);
+	}
 
 	g_signal_connect(G_OBJECT(pager->wrap_workspaces_toggle), "toggled", (GCallback) wrap_workspaces_toggled, pager);
 
