@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -53,7 +53,7 @@ typedef struct {
 } AppletPropertyInfo;
 
 static const AppletPropertyInfo applet_properties [] = {
-	{ "prefs-key",   "PrefsKey" },
+	{ "prefs-path",   "PrefsPath" },
 	{ "orient",      "Orient" },
 	{ "size",        "Size" },
 	{ "size-hints",  "SizeHints" },
