@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  *
  * Most of the original code come from menu.c
  *
@@ -81,6 +81,11 @@ panel_context_menu_show_about_dialog (GtkWidget *menuitem)
 {
 	static GtkWidget *about = NULL;
 	char             *authors [] = {
+		/* MATE */
+		"Perberos <perberos@gmail.com>",
+		"Stefano Karapetsas <stefano@karapetsas.com>",
+		"Steve Zesch <stevezesch2@gmail.com>",
+		/* GNOME */
 		"Alex Larsson <alexl@redhat.com>",
 		"Anders Carlsson <andersca@gnu.org>",
 		"Arvind Samptur <arvind.samptur@wipro.com>",
